from autofit.mock.mock import MockDataset


# def test_load():
#     dataset = MockDataset()
#     assert dataset.name == MockDataset.load(f"/tmp/dataset.pickle").name
